@@ -39,17 +39,17 @@ SEXP git2r_blob_content(SEXP blob)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_blob(blob))
-        git2r_error(git2r_err_blob_arg, __func__, "blob");
+        git2r_error(__func__, NULL, "'blob'", git2r_err_blob_arg);
 
     repository = git2r_repository_open(GET_SLOT(blob, Rf_install("repo")));
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     sha = GET_SLOT(blob, Rf_install("sha"));
     git_oid_fromstr(&oid, CHAR(STRING_ELT(sha, 0)));
 
     err = git_blob_lookup(&blob_obj, repository, &oid);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     PROTECT(result = allocVector(STRSXP, 1));
@@ -65,8 +65,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -89,11 +89,11 @@ SEXP git2r_blob_create_fromdisk(SEXP repo, SEXP path)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_string_vec(path))
-        git2r_error(git2r_err_string_vec_arg, __func__, "path");
+        git2r_error(__func__, NULL, "'path'", git2r_err_string_vec_arg);
 
     repository = git2r_repository_open(repo);
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     len = length(path);
     PROTECT(result = allocVector(VECSXP, len));
@@ -105,11 +105,11 @@ SEXP git2r_blob_create_fromdisk(SEXP repo, SEXP path)
                 &oid,
                 repository,
                 CHAR(STRING_ELT(path, i)));
-            if (GIT_OK != err)
+            if (err)
                 goto cleanup;
 
             err = git_blob_lookup(&blob, repository, &oid);
-            if (GIT_OK != err)
+            if (err)
                 goto cleanup;
 
             SET_VECTOR_ELT(result, i, item = NEW_OBJECT(MAKE_CLASS("git_blob")));
@@ -125,8 +125,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -153,11 +153,11 @@ SEXP git2r_blob_create_fromworkdir(SEXP repo, SEXP relative_path)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_string_vec(relative_path))
-        git2r_error(git2r_err_string_vec_arg, __func__, "relative_path");
+        git2r_error(__func__, NULL, "'relative_path'", git2r_err_string_vec_arg);
 
     repository = git2r_repository_open(repo);
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     len = length(relative_path);
     PROTECT(result = allocVector(VECSXP, len));
@@ -169,11 +169,11 @@ SEXP git2r_blob_create_fromworkdir(SEXP repo, SEXP relative_path)
                 &oid,
                 repository,
                 CHAR(STRING_ELT(relative_path, i)));
-            if (GIT_OK != err)
+            if (err)
                 goto cleanup;
 
             err = git_blob_lookup(&blob, repository, &oid);
-            if (GIT_OK != err)
+            if (err)
                 goto cleanup;
 
             SET_VECTOR_ELT(result, i, item = NEW_OBJECT(MAKE_CLASS("git_blob")));
@@ -189,8 +189,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -230,17 +230,17 @@ SEXP git2r_blob_is_binary(SEXP blob)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_blob(blob))
-        git2r_error(git2r_err_blob_arg, __func__, "blob");
+        git2r_error(__func__, NULL, "'blob'", git2r_err_blob_arg);
 
     repository= git2r_repository_open(GET_SLOT(blob, Rf_install("repo")));
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     sha = GET_SLOT(blob, Rf_install("sha"));
     git_oid_fromstr(&oid, CHAR(STRING_ELT(sha, 0)));
 
     err = git_blob_lookup(&blob_obj, repository, &oid);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     PROTECT(result = allocVector(LGLSXP, 1));
@@ -259,8 +259,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -281,17 +281,17 @@ SEXP git2r_blob_rawsize(SEXP blob)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_blob(blob))
-        git2r_error(git2r_err_blob_arg, __func__, "blob");
+        git2r_error(__func__, NULL, "'blob'", git2r_err_blob_arg);
 
     repository= git2r_repository_open(GET_SLOT(blob, Rf_install("repo")));
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     sha = GET_SLOT(blob, Rf_install("sha"));
     git_oid_fromstr(&oid, CHAR(STRING_ELT(sha, 0)));
 
     err = git_blob_lookup(&blob_obj, repository, &oid);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     size = git_blob_rawsize(blob_obj);
@@ -303,8 +303,8 @@ cleanup:
     if (repository)
         git_repository_free(repository);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return ScalarInteger(size);
 }
